django-modeltrans - Translate model fields using a JSONField — django-modeltrans 0.0.6 documentation

# django-modeltrans - Translate model fields using a `JSONField`

- Uses one `django.contrib.postgres.JSONField` (PostgreSQL jsonb field) for every record.
- Django 1.9, 1.10, 1.11
- PostgreSQL >= 9.4 and Psycopg2 >= 2.5.4.

About the app:

- Available on pypi
- Tested with python 2.7, 3.3, 3.4, 3.5 and Django 1.8, 1.9, Travis CI
- Documentation on readthedocs.org
- Bug tracker

## Table of contents

Documentation

- Getting started
- Inner workings
- Related packages

Reference

- API Reference
- Settings Reference
- Migrating from django-modeltranslation
- django-modeltrans change log